@@ -82,15 +82,15 @@ class TradeApi(AbsTradeApi):
                 _price = _price - _sellSlippage.value
 
         _positionsBeforeDeal = copy.deepcopy(self.__backTestContext.getPosition(tc, symbol))
-
         _success = self.__backTestContext.updatePositionAfterDeal(tc, symbol, side, _price * _quantity, _quantity)
+
         if not _success:
             print("order failed")
             return None
 
         _positionsAfterDeal = copy.deepcopy(self.__backTestContext.getPosition(tc, symbol))
 
-        orderSignal.executedCallBack()
+        orderSignal.executedCallBack(True)
 
         _testOrder = BackTestOrder.build(
             _currentTimeMills, tc, symbol, side, "market", _price, _quantity,
